#include "../df_lua_files.h"
#include <algorithm>

std::string fileExtension( const std::string &filePath )
{
    std::string::size_type pos = filePath.find_last_of( '.' );
    if( pos != std::string::npos )
    {
        std::string lFilePath( filePath.substr( pos + 1 ) );
        std::transform( lFilePath.begin(), lFilePath.end(), lFilePath.begin(), ::tolower );
        return lFilePath;
    }

    return std::string();
}

int l_writeFile( lua_State *L )
{
    // Channel-Data
    LuaChannel *lc = checkchannel( L );
    // Device
    int deviceAddress = static_cast<int>( luaL_checkinteger( L, 2 ) );
    luaL_argcheck( L, deviceAddress >= 1 && deviceAddress <= 254, 2, "out of range" );
    // Die zu bertragnede Datei.
    const char *filePath = luaL_checkstring( L, 3 );
    std::string extension( fileExtension( filePath ) );
    int res = 0;

    if ( extension == "aes" || extension == "ael" )
    {
        // DFCSetupLaden
	    // *.aes; *.ael;
        lua_pushboolean( L, DFCSetupLaden( lc->id, deviceAddress, const_cast<char *>( filePath ), &lc->errorNumber ) );
        res++;
    }
    else if ( extension == "hex" || extension == "dfz" )
    {
	    // DFCUpload
	    // *.hex; *.dfz;
        lua_pushboolean( L, DFCUpload( lc->id, deviceAddress, const_cast<char *>( filePath ), &lc->errorNumber ) );
        res++;
    }
    else if ( extension == "up3" || extension == "up4" || extension == "up5" )
    {
	    // DFCUploadModule
	    // *.up3; *.up4; *.up5;
        lua_pushboolean( L, DFCUploadModule( lc->id, deviceAddress, 0, const_cast<char *>( filePath ), &lc->errorNumber ) );
        res++;
    }
    else
    {	
        // Optional Flags
        int flags = static_cast<int>( luaL_optinteger( L, 4, 0 ) );
	    // DFCFileUpload
	    // *.dfl; *.dfk; *.dfc; *.df0; *.df1;
        int fileType = -1;
        if ( extension == "dfl" ) // Languagefile
            fileType = 0;
        else if ( extension == "dfk" ) // Touchkeydefines
            fileType = 1;
        else if ( extension == "dfc" ) // Colormapfile
            fileType = 2;
        else if ( extension == "df0" ) // WLAN-Config
            fileType = 3;
        //else if ( extension == "df1" ) HIP-Config, bleibt bei fileType == -1 die Endung ist entscheident.

        lua_pushboolean( L, DFCFileUpload( lc->id, deviceAddress, fileType, const_cast<char *>( filePath ), flags, &lc->errorNumber ) );
        res++;
    }

    if ( res && lua_toboolean( L, -1 ) == false )
        push_errorNumber( lc, res );

    return res;
}

int l_readFile( lua_State *L )
{
    // Channel-Data
    LuaChannel *lc = checkchannel( L );
    // Device
    int deviceAddress = static_cast<int>( luaL_checkinteger( L, 2 ) );
    luaL_argcheck( L, deviceAddress >= 1 && deviceAddress <= 254, 2, "out of range" );
    // Die zu bertragnede Datei.
    const char *filePath = luaL_checkstring( L, 3 );
    std::string extension( fileExtension( filePath ) );
    int res = 0;

    if ( extension == "aes" || extension == "ael" )
    {
	    // DFCDownload
	    // *.aes; *.ael;
        lua_pushboolean( L, DFCDownload( lc->id, deviceAddress, const_cast<char *>( filePath ), &lc->errorNumber ) );
        res++;
    }
    else
    {
        // Optional Flags
        int flags = static_cast<int>( luaL_optinteger( L, 4, 0 ) );
	    // DFCFileDownload
	    // *.dfl; *.dfk; *.dfc; -> IV_ERROR_FUNCTION_UNAVAILABLE
	    // *.df0; *.df1; *.*;
        int fileType = -1;
	    if ( extension == "df0" )
            fileType = 3;

        lua_pushboolean( L, DFCFileDownload( lc->id, deviceAddress, fileType, const_cast<char *>( filePath ), flags, &lc->errorNumber ) );
        res++;
    }

    if ( res && lua_toboolean( L, -1 ) == false )
        push_errorNumber( lc, res );

    return res;
}

int l_editFile( lua_State *L )
{
    // Die Quelldatei.
    const char *sourceFilePath = luaL_checkstring( L, 1 );
    // Die Zieldatei.
    const char *destFilePath = luaL_checkstring( L, 2 );
    // Die Modifizierungsdaten oder Datei.
    const char *xmlData = luaL_checkstring( L, 3 );
    // Optional Flags
    int flags = static_cast<int>( luaL_optinteger( L, 4, 0 ) );
    // Fehlernummer
    int errorNumber;

    lua_pushboolean( L, DFCModifyStudioFile( const_cast<char *>( sourceFilePath ), const_cast<char *>( destFilePath ), const_cast<char *>( xmlData ), flags, &errorNumber ) );
    if ( lua_toboolean( L, -1 ) == false )
    {
        int res = 1;
        push_globalErrorNumber( errorNumber, res );
        return res;
    }

    return 1;
}
