/*############################################################################*/
/** \file power.h

Routinen zur Steuerung der Energiemanagements.

*/
/*############################################################################*/

#ifndef _POWER_H_
#define _POWER_H_
#pragma pack(push, 1)

#define POWER_PROFIL_COUNT                       4  ///< Anzahl der möglichen Energieschemen
#define POWER_PROFIL_UNITS                       14 ///< Anzahl der auswählbaren Module CPU, Display usw.
#define POWER_PROFIL_ITEMS                       14 ///< Anzahl der auswählbaren Energieoptionen für AN, AUS usw.
#define POWER_EVENT_COUNT                        22 ///< Anzahl der definierten Events
#define POWER_EVENT_MAX                          22 ///< Anzahl der max. selektierbaren Events pro Energieschema
#define POWER_EVENT_TIMER_A_MAX  POWER_PROFIL_COUNT ///< Anzahl der Systemtimer, mögliche mit Timeout
#define POWER_EVENT_TIMER_B_MAX                   8 ///< Anzahl der Systemtimer, mögliche per Uhrzeit

//#define POWER_PROFILE_NAME_0                     _T("Betrieb")
//#define POWER_PROFILE_NAME_1                     _T("Sparmodus")
//#define POWER_PFOFILE_NAME_TURN_OFF              _T("Abschalten")
//#define POWER_PROFILE_NAME_0                    QT_TR_NOOP( "Power", "Betrieb" )
//#define POWER_PROFILE_NAME_1                    QT_TR_NOOP( "Power", "Sparmodus" ) 
//#define POWER_PFOFILE_NAME_TURN_OFF             QT_TR_NOOP( "Power", "Abschalten" )


#define POWER_DEFAULT_PROFILE                    hal_POWER_DEFAULT_PROFILE

//Auswahlpunkte der Module
#define POWER_ITEM_NR_OFF                        0  ///< Aus
#define POWER_ITEM_NR_ON                         1  ///< Ein
#define POWER_ITEM_NR_KEEP                       2  ///< Beibehalten aus vorausgegangenem Schema
#define POWER_ITEM_NR_SLEEP                      3  ///< Sleep-Mode
#define POWER_ITEM_NR_SERVICE_TIMEOUT            4  ///< Bedienung-TimeOut
#define POWER_ITEM_NR_CHAIN_FIELD                5  ///< EIN, wenn Modul in aktiver Feldfunktion benutzt wird
#define POWER_ITEM_NR_DISPLAY_DARK               6  ///< Beleuchtung Display Dunkel
#define POWER_ITEM_NR_SEND_RECORDS               7  ///< Kommunikation "Ein" wenn Datensätze vorhanden sind, "Aus" nach Timeout
#define POWER_ITEM_NR_COM_ON                     8  ///< Kommunikation Zyklisch "Ein", nach Datenübertragung wieder "Aus" nach TimeOut, Aktivierungszeit in h oder als Uhrzeit
#define POWER_ITEM_NR_USBHOST_MENUE              9  ///< Nur Ein im BIOS-Menü
#define POWER_ITEM_NR_GPS_CYCLE                  10 ///< Zyklischer Betrieb Ein bis gültige Daten vorhanden sind und Zeitwert für Aus muss angegeben werden, Aktivierungszeit in h oder als Uhrzeit
#define POWER_ITEM_NR_MACHINE_RUNS               11 ///< Maschine läuft(Start)
#define POWER_ITEM_NR_MACHINE_STOP               12 ///< Maschine steht(Stopp)
#define POWER_ITEM_NR_TB_TIMEOUT                 13 ///< Timeboy Steckevent EIN und nach TimeOut z.B. 10h wieder AUS
#define POWER_ITEM_NR_DIGITAL_IN				 11 ///< Digitaler Eingang wird verwendet
#define POWER_ITEM_NR_HIGH_OFF					  0 ///< Der High Pegel des verwendeten digitalen Eingangs schaltet das GPS Modul AUS
#define POWER_ITEM_NR_HIGH_ON					  1 ///< Der High Pegel des verwendeten digitalen Eingangs schaltet das GPS Modul EIN
#define POWER_ITEM_NR_TOFF                       14 ///< EIN, wenn digitaler Eingang x min. 1s HIGH wird. AUS wenn digitaler Eingang x wieder min. 1s LOW ist und eingestellter Timeout abgelaufen.
#define POWER_ITEM_NR_TON                        15 ///< EIN, wenn digitaler Eingang x min. 1s HIGH ist und eingestellter Timeout abgelaufen. AUS wenn digitaler Eingang x wieder min. 1s LOW ist.
#define POWER_ITEM_NR_STANDBY                    16 ///< Modul wird nur bei Bedarf aktiviert. Kann eventl. Verzögerungen hervorrufen.
#define POWER_ITEM_NR_TB_SLOT                    17 ///< EIN, wenn digitaler Eingang x min. 1s HIGH wird. AUS wenn digitaler Eingang x wieder min. 1s LOW ist und eingestellter Timeout abgelaufen.
                                                    ///< Zusaetzlich wird bei AUS, wenn Listendaten fuer Timeboys vorliegen, alle 2 Minuten nach zu aktualisierenden Timeboys geschaut.


//Auswahlpunkte der Module
//#define TEXT_POWER_ITEM_NR_OFF                        _T("Aus")           ///< AUS
//#define TEXT_POWER_ITEM_NR_ON                         _T("Ein")           ///< EIN
//#define TEXT_POWER_ITEM_NR_KEEP                       _T("Beibehalten")   ///< Beibehalten aus vorausgegangenem Schema
//#define TEXT_POWER_ITEM_NR_SLEEP                      _T("Sleep-Mode")    ///< Sleep-Mode
//#define TEXT_POWER_ITEM_NR_SERVICE_TIMEOUT            _T("Eingabe")       ///< Bedienung-TimeOut
//#define TEXT_POWER_ITEM_NR_CHAIN_FIELD                _T("Feldfunktion")  ///< EIN, wenn Modul in aktiver Feldfunktion benutzt wird
//#define TEXT_POWER_ITEM_NR_DISPLAY_DARK               _T("Helligkeit")    ///< Beleuchtung Display Dunkel
//#define TEXT_POWER_ITEM_NR_SEND_RECORDS               _T("Datensatz")     ///< Kommunikation "Ein" wenn Datensätze vorhanden sind, "Aus" nach Timeout
//#define TEXT_POWER_ITEM_NR_COM_ON                     _T("Zyklisch")      ///< Kommunikation Zyklisch "Ein", nach Datenübertragung wieder "Aus" nach TimeOut, Aktivierungszeit in h oder als Uhrzeit
//#define TEXT_POWER_ITEM_NR_USBHOST_MENUE              _T("Bios")          ///< Nur Ein im BIOS-Menü
//#define TEXT_POWER_ITEM_NR_GPS_CYCLE                  _T("Zyklisch")      ///< Zyklischer Betrieb Ein bis gültige Daten vorhanden sind und Zeitwert für Aus muss angegeben werden, Aktivierungszeit in h oder als Uhrzeit
//#define TEXT_POWER_ITEM_NR_MACHINE_RUNS               _T("Start")         ///< Maschine läuft(Start)
//#define TEXT_POWER_ITEM_NR_MACHINE_STOP               _T("Stopp")         ///< Maschine steht(Stopp)
//#define TEXT_POWER_ITEM_NR_TB_TIMEOUT                 _T("Timeboy")       ///< Timeboy Steckevent EIN und nach TimeOut z.B. 10h wieder AUS
//#define TEXT_POWER_ITEM_NR_DIGITAL_IN				  _T("Dig.-Eingang")  ///< Digitaler Eingang wird verwendet
//#define TEXT_POWER_ITEM_NR_HIGH_OFF					  _T("High->AUS")     ///< Der High Pegel des verwendeten digitalen Eingangs schaltet das GPS Modul AUS
//#define TEXT_POWER_ITEM_NR_HIGH_ON					  _T("High->EIN")     ///< Der High Pegel des verwendeten digitalen Eingangs schaltet das GPS Modul EIN
//#define TEXT_POWER_ITEM_NR_TOFF                       _T("Aus nach")      ///< EIN, wenn digitaler Eingang x min. 1s HIGH wird. AUS wenn digitaler Eingang x wieder min. 1s LOW ist und eingestellter Timeout abgelaufen.
//#define TEXT_POWER_ITEM_NR_CPU_TOFF                   _T("Sleep nach")    ///< EIN, wenn digitaler Eingang x min. 1s HIGH wird. AUS wenn digitaler Eingang x wieder min. 1s LOW ist und eingestellter Timeout abgelaufen.
//#define TEXT_POWER_ITEM_NR_TON                        _T("Ein nach")      ///< EIN, wenn digitaler Eingang x min. 1s HIGH ist und eingestellter Timeout abgelaufen. AUS wenn digitaler Eingang x wieder min. 1s LOW ist.
//#define TEXT_POWER_ITEM_NR_STANDBY                    _T("Standby")       ///< EIN, nur bei Bedarf. Verzoegerungen durch Hochlaufzeit moeglich.
//#define TEXT_POWER_ITEM_NR_TB_SLOT                    _T("Docking")       ///< EIN, wenn digitaler Eingang x min. 1s HIGH wird. AUS wenn digitaler Eingang x wieder min. 1s LOW ist und eingestellter Timeout abgelaufen.
                                                                            ///< Zusaetzlich wird bei AUS, wenn Listendaten fuer Timeboys vorliegen, alle 2 Minuten nach zu aktualisierenden Timeboys geschaut.
// #define TEXT_POWER_ITEM_NR_OFF						  QT_TR_NOOP( "Power", "Aus" )           ///< AUS
// #define TEXT_POWER_ITEM_NR_ON                         QT_TR_NOOP( "Power", "Ein" )           ///< EIN
// #define TEXT_POWER_ITEM_NR_KEEP                       QT_TR_NOOP( "Power", "Beibehalten" )   ///< Beibehalten aus vorausgegangenem Schema
// #define TEXT_POWER_ITEM_NR_SLEEP                      QT_TR_NOOP( "Power", "Sleep-Mode" )    ///< Sleep-Mode
// #define TEXT_POWER_ITEM_NR_SERVICE_TIMEOUT            QT_TR_NOOP( "Power", "Eingabe" )       ///< Bedienung-TimeOut
// #define TEXT_POWER_ITEM_NR_CHAIN_FIELD                QT_TR_NOOP( "Power", "Feldfunktion" )  ///< EIN, wenn Modul in aktiver Feldfunktion benutzt wird
// #define TEXT_POWER_ITEM_NR_DISPLAY_DARK               QT_TR_NOOP( "Power", "Helligkeit" )    ///< Beleuchtung Display Dunkel
// #define TEXT_POWER_ITEM_NR_SEND_RECORDS               QT_TR_NOOP( "Power", "Datensatz" )     ///< Kommunikation "Ein" wenn Datensätze vorhanden sind, "Aus" nach Timeout
// #define TEXT_POWER_ITEM_NR_COM_ON                     QT_TR_NOOP( "Power", "Zyklisch" )      ///< Kommunikation Zyklisch "Ein", nach Datenübertragung wieder "Aus" nach TimeOut, Aktivierungszeit in h oder als Uhrzeit
// #define TEXT_POWER_ITEM_NR_USBHOST_MENUE              QT_TR_NOOP( "Power", "Bios" )          ///< Nur Ein im BIOS-Menü
// #define TEXT_POWER_ITEM_NR_GPS_CYCLE                  QT_TR_NOOP( "Power", "Zyklisch" )      ///< Zyklischer Betrieb Ein bis gültige Daten vorhanden sind und Zeitwert für Aus muss angegeben werden, Aktivierungszeit in h oder als Uhrzeit
// #define TEXT_POWER_ITEM_NR_MACHINE_RUNS               QT_TR_NOOP( "Power", "Start" )         ///< Maschine läuft(Start)
// #define TEXT_POWER_ITEM_NR_MACHINE_STOP               QT_TR_NOOP( "Power", "Stopp" )         ///< Maschine steht(Stopp)
// #define TEXT_POWER_ITEM_NR_TB_TIMEOUT                 QT_TR_NOOP( "Power", "Timeboy" )       ///< Timeboy Steckevent EIN und nach TimeOut z.B. 10h wieder AUS
// #define TEXT_POWER_ITEM_NR_DIGITAL_IN				  QT_TR_NOOP( "Power", "Dig.-Eingang" )  ///< Digitaler Eingang wird verwendet
// #define TEXT_POWER_ITEM_NR_HIGH_OFF					  QT_TR_NOOP( "Power", "High->AUS" )     ///< Der High Pegel des verwendeten digitalen Eingangs schaltet das GPS Modul AUS
// #define TEXT_POWER_ITEM_NR_HIGH_ON					  QT_TR_NOOP( "Power", "High->EIN" )     ///< Der High Pegel des verwendeten digitalen Eingangs schaltet das GPS Modul EIN
// #define TEXT_POWER_ITEM_NR_TOFF                       QT_TR_NOOP( "Power", "Aus nach" )      ///< EIN, wenn digitaler Eingang x min. 1s HIGH wird. AUS wenn digitaler Eingang x wieder min. 1s LOW ist und eingestellter Timeout abgelaufen.
// #define TEXT_POWER_ITEM_NR_CPU_TOFF                   QT_TR_NOOP( "Power", "Sleep nach" )    ///< EIN, wenn digitaler Eingang x min. 1s HIGH wird. AUS wenn digitaler Eingang x wieder min. 1s LOW ist und eingestellter Timeout abgelaufen.
// #define TEXT_POWER_ITEM_NR_TON                        QT_TR_NOOP( "Power", "Ein nach" )      ///< EIN, wenn digitaler Eingang x min. 1s HIGH ist und eingestellter Timeout abgelaufen. AUS wenn digitaler Eingang x wieder min. 1s LOW ist.
// #define TEXT_POWER_ITEM_NR_STANDBY                    QT_TR_NOOP( "Power", "Standby" )       ///< EIN, nur bei Bedarf. Verzoegerungen durch Hochlaufzeit moeglich.
// #define TEXT_POWER_ITEM_NR_TB_SLOT                    QT_TR_NOOP( "Power", "Docking" )       ///< EIN, wenn digitaler Eingang x min. 1s HIGH wird. AUS wenn digitaler Eingang x wieder min. 1s LOW ist und eingestellter Timeout abgelaufen.

//Module, Baugruppen
#define POWER_MODULE_NR_CPU                      1  ///< CPU
#define POWER_MODULE_NR_TIMER                    2  ///< Timer 
#define POWER_MODULE_NR_INPUTS                   3  ///< Eingänge
#define POWER_MODULE_NR_GLOBAL                   4  ///< Global Alles
#define POWER_MODULE_NR_12V_EXT                  5  ///< 12V extern
#define POWER_MODULE_NR_5V_EXT                   6  ///< 5V extern
#define POWER_MODULE_NR_COMMUNICATION            7  ///< Kommunikation
#define POWER_MODULE_NR_DISPLAY_LIGHT            8  ///< Display Beleuchtung
#define POWER_MODULE_NR_DISPLAY_TEXT             9  ///< Display Text
#define POWER_MODULE_NR_FINGERPRINT              10 ///< Biokey
#define POWER_MODULE_NR_TP                       11 ///< Transponder
#define POWER_MODULE_NR_GPS                      12 ///< GPS
#define POWER_MODULE_NR_USBHOST                  13 ///< USB-Host
#define POWER_MODULE_NR_MMC                      14 ///< MMC

//#define TEXT_MODULE_NR_SYSTEM                    _T("System")                   ///< NA
//#define TEXT_MODULE_NR_CPU                       _T("CPU")                      ///< CPU
//#define TEXT_MODULE_NR_TIMER                     _T("Timer")                    ///< Timer 
//#define TEXT_MODULE_NR_INPUTS                    _T("Eingänge")                 ///< Eingänge
//#define TEXT_MODULE_NR_GLOBAL                    _T("Global Alles")             ///< Global Alles
//#define TEXT_MODULE_NR_12V_EXT                   _T("12V extern")               ///< 12V extern
//#define TEXT_MODULE_NR_5V_EXT                    _T("5V extern")                ///< 5V extern
//#define TEXT_MODULE_NR_COMMUNICATION             _T("Kommunikation")            ///< Kommunikation
//#define TEXT_MODULE_NR_DISPLAY_LIGHT             _T("Display Beleuchtung")      ///< Display Beleuchtung
//#define TEXT_MODULE_NR_DISPLAY_TEXT              _T("Display Text")             ///< Display Text
//#define TEXT_MODULE_NR_FINGERPRINT               _T("Biokey")                   ///< Biokey
//#define TEXT_MODULE_NR_TP                        _T("Transponder")              ///< Transponder
//#define TEXT_MODULE_NR_GPS                       _T("GPS")                      ///< GPS
//#define TEXT_MODULE_NR_USBHOST                   _T("USB-Host")                 ///< USB-Host
//#define TEXT_MODULE_NR_MMC                       _T("MMC")                      ///< MMC
// #define TEXT_MODULE_NR_SYSTEM                    QT_TR_NOOP( "Power", "System" )                   ///< NA
// #define TEXT_MODULE_NR_CPU                       QT_TR_NOOP( "Power", "CPU" )                      ///< CPU
// #define TEXT_MODULE_NR_TIMER                     QT_TR_NOOP( "Power", "Timer" )                    ///< Timer 
// #define TEXT_MODULE_NR_INPUTS                    QT_TR_NOOP( "Power", "Eingänge" )                 ///< Eingänge
// #define TEXT_MODULE_NR_GLOBAL                    QT_TR_NOOP( "Power", "Global Alles" )             ///< Global Alles
// #define TEXT_MODULE_NR_12V_EXT                   QT_TR_NOOP( "Power", "12V extern" )               ///< 12V extern
// #define TEXT_MODULE_NR_5V_EXT                    QT_TR_NOOP( "Power", "5V extern" )                ///< 5V extern
// #define TEXT_MODULE_NR_COMMUNICATION             QT_TR_NOOP( "Power", "Kommunikation" )            ///< Kommunikation
// #define TEXT_MODULE_NR_DISPLAY_LIGHT             QT_TR_NOOP( "Power", "Display Beleuchtung" )      ///< Display Beleuchtung
// #define TEXT_MODULE_NR_DISPLAY_TEXT              QT_TR_NOOP( "Power", "Display Text" )             ///< Display Text
// #define TEXT_MODULE_NR_FINGERPRINT               QT_TR_NOOP( "Power", "Biokey" )                   ///< Biokey
// #define TEXT_MODULE_NR_TP                        QT_TR_NOOP( "Power", "Transponder" )              ///< Transponder
// #define TEXT_MODULE_NR_GPS                       QT_TR_NOOP( "Power", "GPS" )                      ///< GPS
// #define TEXT_MODULE_NR_USBHOST                   QT_TR_NOOP( "Power", "USB-Host" )                 ///< USB-Host
// #define TEXT_MODULE_NR_MMC                       QT_TR_NOOP( "Power", "MMC" )                      ///< MMC

//Flags Module
#define POWER_MODULE_CPU                         0x00000001 ///< CPU
#define POWER_MODULE_TIMER                       0x00000002 ///< Timer 
#define POWER_MODULE_INPUTS                      0x00000004 ///< Eingänge
#define POWER_MODULE_GLOBAL                      0x00000008 ///< Global Alles
#define POWER_MODULE_5V_EXT                      0x00000010 ///< 5V extern
#define POWER_MODULE_12V_EXT                     0x00000020 ///< 12V extern
#define POWER_MODULE_COMMUNICATION               0x00000040 ///< Kommunikation
#define POWER_MODULE_DISPLAY_LIGHT               0x00000080 ///< Display Beleuchtung
#define POWER_MODULE_DISPLAY_TEXT                0x00000100 ///< Display Text
#define POWER_MODULE_FINGERPRINT                 0x00000200 ///< Biokey
#define POWER_MODULE_TP                          0x00000400 ///< Transponder
#define POWER_MODULE_GPS                         0x00000800 ///< GPS
#define POWER_MODULE_USBHOST                     0x00001000 ///< USB-Host
#define POWER_MODULE_MMC                         0x00002000 ///< MMC

//Events
#define POWER_EVENT_NR_TIMER_A                   0x01 ///< Systemtimer Typ A mit Aktivzeit
#define POWER_EVENT_NR_TIMER_B                   0x02 ///< Systemtimer Typ B mit Uhrzeit
#define POWER_EVENT_NR_KEY_PRESSED               0x03 ///< Eingabeereignis(Tastatur, Biokey, Transponder, Barcode)
#define POWER_EVENT_NR_KEY_TIMEOUT_1             0x04 ///< Eingabe TimeOut 1
#define POWER_EVENT_NR_KEY_TIMEOUT_2             0x05 ///< Eingabe TimeOut 2
#define POWER_EVENT_NR_USB                       0x06 ///< Stromversorgung über USB aktiviert
#define POWER_EVENT_NR_BATTERY                   0x07 ///< Stromversorgung über Batterie aktiviert
#define POWER_EVENT_NR_LINE_IN                   0x08 ///< Stromversorgung über Netzteil aktiviert
#define POWER_EVENT_NR_BAT_LOW                   0x09 ///< Batteriezustand niedrig
#define POWER_EVENT_NR_BAT_EMPTY                 0x0A ///< Batteriezustand leer
#define POWER_EVENT_NR_SWITCH_ON                 0x0B ///< Ein-/Ausschalter schaltet EIN
#define POWER_EVENT_NR_SWITCH_OFF                0x0C ///< Ein-/Ausschalter schaltet AUS
#define POWER_EVENT_NR_TB_PLUGIN                 0x0D ///< Timeboy-Steck-Event
#define POWER_EVENT_NR_TB_PLUGOUT                0x0E ///< Timeboy-Zieh-Event
#define POWER_EVENT_NR_MDE_START                 0x0F ///< Start-Erkennung MDE
#define POWER_EVENT_NR_MDE_STOP                  0x10 ///< Stopp-Erkennung MDE
#define POWER_EVENT_NR_ANALOG_OVER_VALUE         0x11 ///< Analogwertüberwachung Messwert Überschreitung
#define POWER_EVENT_NR_ANALOG_UNDER_VALUE        0x12 ///< Analogwertüberwachung Messwert Unterschreitung
#define POWER_EVENT_NR_MOVE_START                0x13 ///< Bewegungserkennung Start
#define POWER_EVENT_NR_MOVE_STOP                 0x14 ///< Bewegungserkennung Stopp
#define POWER_EVENT_NR_COMMUNICATION             0x15 ///< Kommunikation
#define POWER_EVENT_NR_COMMUNICATION_TIMEOUT     0x16 ///< KommunikationsTimeOut

//#define TEXT_EVENT_NR_TIMER_A                   _T("Systemtimer -> Timeout")                  ///< Systemtimer Typ A mit Aktivzeit
//#define TEXT_EVENT_NR_TIMER_B                   _T("Systemtimer -> Uhrzeit")                  ///< Systemtimer Typ B mit Uhrzeit
//#define TEXT_EVENT_NR_KEY_PRESSED               _T("Eingabe -> Tastatur, Transponder etc.")   ///< Eingabeereignis(Tastatur, Biokey, Transponder, Barcode)
//#define TEXT_EVENT_NR_KEY_TIMEOUT_1             _T("Eingabe -> Timeout")                      ///< Eingabe TimeOut 1
//#define TEXT_EVENT_NR_KEY_TIMEOUT_2             _T("Eingabe -> Timeout 2")                    ///< Eingabe TimeOut 2
//#define TEXT_EVENT_NR_USB                       _T("Stromversorgung -> USB")                  ///< Stromversorgung über USB aktiviert
//#define TEXT_EVENT_NR_BATTERY                   _T("Stromversorgung -> Akku")                 ///< Stromversorgung über Batterie aktiviert
//#define TEXT_EVENT_NR_LINE_IN                   _T("Stromversorgung -> Netzteil")             ///< Stromversorgung über Netzteil aktiviert
//#define TEXT_EVENT_NR_BAT_LOW                   _T("Ladezustand Akku -> Niedrig")             ///< Batteriezustand niedrig
//#define TEXT_EVENT_NR_BAT_EMPTY                 _T("Ladezustand Akku -> Leer")                ///< Batteriezustand leer
//#define TEXT_EVENT_NR_SWITCH_ON                 _T("Ein/Aus-Schalter -> EIN")                 ///< Ein-/Ausschalter schaltet EIN
//#define TEXT_EVENT_NR_SWITCH_OFF                _T("Ein/Aus-Schalter -> AUS")                 ///< Ein-/Ausschalter schaltet AUS
//#define TEXT_EVENT_NR_TB_PLUGIN                 _T("Timeboy -> Einstecken")                   ///< Timeboy-Steck-Event
//#define TEXT_EVENT_NR_TB_PLUGOUT                _T("Timeboy -> Herausziehen")                 ///< Timeboy-Zieh-Event
//#define TEXT_EVENT_NR_MDE_START                 _T("Digitaler Eingang: Low->High")            ///< Start-Erkennung MDE
//#define TEXT_EVENT_NR_MDE_STOP                  _T("Digitaler Eingang: High->Low")            ///< Stopp-Erkennung MDE
//#define TEXT_EVENT_NR_ANALOG_OVER_VALUE         _T("Analogwert -> Überschreitung")            ///< Analogwertüberwachung Messwert Überschreitung
//#define TEXT_EVENT_NR_ANALOG_UNDER_VALUE        _T("Analogwert -> Unterschreitung")           ///< Analogwertüberwachung Messwert Unterschreitung
//#define TEXT_EVENT_NR_MOVE_START                _T("Bewegungserkennung -> Start")             ///< Bewegungserkennung Start
//#define TEXT_EVENT_NR_MOVE_STOP                 _T("Bewegungserkennung -> Stopp")             ///< Bewegungserkennung Stopp
//#define TEXT_EVENT_NR_COMMUNICATION             _T("Kommunikation")                           ///< Kommunikation
//#define TEXT_EVENT_NR_COMMUNICATION_TIMEOUT     _T("Kommunikation -> Ablauf Timeout")         ///< KommunikationsTimeOut
// #define TEXT_EVENT_NR_TIMER_A                   QT_TR_NOOP( "Power", "Systemtimer -> Timeout" )                  ///< Systemtimer Typ A mit Aktivzeit
// #define TEXT_EVENT_NR_TIMER_B                   QT_TR_NOOP( "Power", "Systemtimer -> Uhrzeit" )                  ///< Systemtimer Typ B mit Uhrzeit
// #define TEXT_EVENT_NR_KEY_PRESSED               QT_TR_NOOP( "Power", "Eingabe -> Tastatur, Transponder etc." )   ///< Eingabeereignis(Tastatur, Biokey, Transponder, Barcode)
// #define TEXT_EVENT_NR_KEY_TIMEOUT_1             QT_TR_NOOP( "Power", "Eingabe -> Timeout" )                      ///< Eingabe TimeOut 1
// #define TEXT_EVENT_NR_KEY_TIMEOUT_2             QT_TR_NOOP( "Power", "Eingabe -> Timeout 2" )                    ///< Eingabe TimeOut 2
// #define TEXT_EVENT_NR_USB                       QT_TR_NOOP( "Power", "Stromversorgung -> USB" )                  ///< Stromversorgung über USB aktiviert
// #define TEXT_EVENT_NR_BATTERY                   QT_TR_NOOP( "Power", "Stromversorgung -> Akku" )                 ///< Stromversorgung über Batterie aktiviert
// #define TEXT_EVENT_NR_LINE_IN                   QT_TR_NOOP( "Power", "Stromversorgung -> Netzteil" )             ///< Stromversorgung über Netzteil aktiviert
// #define TEXT_EVENT_NR_BAT_LOW                   QT_TR_NOOP( "Power", "Ladezustand Akku -> Niedrig" )             ///< Batteriezustand niedrig
// #define TEXT_EVENT_NR_BAT_EMPTY                 QT_TR_NOOP( "Power", "Ladezustand Akku -> Leer" )                ///< Batteriezustand leer
// #define TEXT_EVENT_NR_SWITCH_ON                 QT_TR_NOOP( "Power", "Ein/Aus-Schalter -> EIN" )                 ///< Ein-/Ausschalter schaltet EIN
// #define TEXT_EVENT_NR_SWITCH_OFF                QT_TR_NOOP( "Power", "Ein/Aus-Schalter -> AUS" )                 ///< Ein-/Ausschalter schaltet AUS
// #define TEXT_EVENT_NR_TB_PLUGIN                 QT_TR_NOOP( "Power", "Timeboy -> Einstecken" )                   ///< Timeboy-Steck-Event
// #define TEXT_EVENT_NR_TB_PLUGOUT                QT_TR_NOOP( "Power", "Timeboy -> Herausziehen" )                 ///< Timeboy-Zieh-Event
// #define TEXT_EVENT_NR_MDE_START                 QT_TR_NOOP( "Power", "Digitaler Eingang: Low->High" )            ///< Start-Erkennung MDE
// #define TEXT_EVENT_NR_MDE_STOP                  QT_TR_NOOP( "Power", "Digitaler Eingang: High->Low" )            ///< Stopp-Erkennung MDE
// #define TEXT_EVENT_NR_ANALOG_OVER_VALUE         QT_TR_NOOP( "Power", "Analogwert -> Überschreitung" )            ///< Analogwertüberwachung Messwert Überschreitung
// #define TEXT_EVENT_NR_ANALOG_UNDER_VALUE        QT_TR_NOOP( "Power", "Analogwert -> Unterschreitung" )           ///< Analogwertüberwachung Messwert Unterschreitung
// #define TEXT_EVENT_NR_MOVE_START                QT_TR_NOOP( "Power", "Bewegungserkennung -> Start" )             ///< Bewegungserkennung Start
// #define TEXT_EVENT_NR_MOVE_STOP                 QT_TR_NOOP( "Power", "Bewegungserkennung -> Stopp" )             ///< Bewegungserkennung Stopp
// #define TEXT_EVENT_NR_COMMUNICATION             QT_TR_NOOP( "Power", "Kommunikation" )                           ///< Kommunikation
// #define TEXT_EVENT_NR_COMMUNICATION_TIMEOUT     QT_TR_NOOP( "Power", "Kommunikation -> Ablauf Timeout" )         ///< KommunikationsTimeOut

//Flags der Energieverwaltung
#define POWER_EVENT_TIMER_A                      0x00000001 ///< Systemtimer Typ A mit Aktivzeit
#define POWER_EVENT_TIMER_B                      0x00000002 ///< Systemtimer Typ B mit Uhrzeit
#define POWER_EVENT_KEY_PRESSED                  0x00000004 ///< Eingabeereignis(Tastatur, Biokey, Transponder, Barcode)
#define POWER_EVENT_KEY_TIMEOUT_1                0x00000008 ///< Eingabe TimeOut 1
#define POWER_EVENT_KEY_TIMEOUT_2                0x00000010 ///< Eingabe TimeOut 2
#define POWER_EVENT_USB                          0x00000020 ///< Stromversorgung über USB aktiviert
#define POWER_EVENT_BATTERY                      0x00000040 ///< Stromversorgung über Batterie aktiviert
#define POWER_EVENT_LINE_IN                      0x00000080 ///< Stromversorgung über Netzteil aktiviert
#define POWER_EVENT_BAT_LOW                      0x00000100 ///< Batteriezustand niedrig
#define POWER_EVENT_BAT_EMPTY                    0x00000200 ///< Batteriezustand leer
#define POWER_EVENT_SWITCH_ON                    0x00000400 ///< Ein-/Ausschalter schaltet EIN
#define POWER_EVENT_SWITCH_OFF                   0x00000800 ///< Ein-/Ausschalter schaltet AUS
#define POWER_EVENT_TB_PLUGIN                    0x00001000 ///< Timeboy-Steck-Event
#define POWER_EVENT_TB_PLUGOUT                   0x00002000 ///< Timeboy-Zieh-Event
#define POWER_EVENT_MDE_START                    0x00004000 ///< Start-Erkennung MDE
#define POWER_EVENT_MDE_STOP                     0x00008000 ///< Stopp-Erkennung MDE
#define POWER_EVENT_ANALOG_OVER_VALUE            0x00010000 ///< Analogwertüberwachung Messwert Überschreitung
#define POWER_EVENT_ANALOG_UNDER_VALUE           0x00020000 ///< Analogwertüberwachung Messwert Unterschreitung
#define POWER_EVENT_MOVE_START                   0x00040000 ///< Bewegungserkennung Start
#define POWER_EVENT_MOVE_STOP                    0x00080000 ///< Bewegungserkennung Stopp
#define POWER_EVENT_COMMUNICATION                0x00100000 ///< Kommunikation
#define POWER_EVENT_COMMUNICATION_TIMEOUT        0x00200000 ///< KommunikationsTimeOut

/**
@struct POWERSETUPNODE enthält Einstellungen und Adressen der Energieschemen
*/

typedef struct struct_power_setup_node {

    unsigned char version;         ///< Versionserkennung
    unsigned char cntProfile;      ///< Anzahl der benutzten Schemen
    unsigned char cntEvents;       ///< Anzahl der benutzten Events
    unsigned char active;          ///< Schema welches nach dem Start des Setup zuerst aktiviert werden soll
    unsigned char temp[2];         ///< Reserve
    unsigned int ptrProfileArray; ///< Zeiger auf das 1. vorhandene Schema mit der Struktur POWERSETUP
    unsigned int ptrEventArray;   ///< Zeiger auf das 1. vorhandene Event mit der Struktur POWEREVENT

} POWERSETUPNODE;

/**
@struct POWERMODULE enthält Einstellungen des einzenlen Moduls
*/

typedef struct struct_power_module {

    unsigned char item;            ///< Auswahl der Energieoption EIN, AUS usw.
    unsigned int time;            ///< Wert der Zeit in Sekunden
    unsigned char value;           ///< Wert für Helligkeit oder andere Größen
    unsigned int interval;        ///< Wert des Einschaltintervall der Zeit in Sekunden (value = 0) oder als Uhrzeit (value = 1)

} POWERMODULE;

/**
@struct POWERSETUP enthält Einstellungen aller Module
*/

typedef struct struct_power_setup
{
    unsigned char name[32];        ///< Name des Schemas
    unsigned char temp[2];         ///< Reserve  
    POWERMODULE cpu;               ///< Einstellungen für Mircrocontroller
    POWERMODULE timer;             ///< Einstellungen für Timer der Signalverarbeitung
    POWERMODULE inputs;            ///< Einstellungen für Eingänge der Signalverarbeitung
    POWERMODULE deviceGlobal;      ///< Einstellungen für Globale Spannungsversorgung der Baugruppe
    POWERMODULE U5V;               ///< Einstellungen für 5V extern
    POWERMODULE U12V;              ///< Einstellungen für 12V extern
    POWERMODULE communication;     ///< Einstellungen für Kommunikation
    POWERMODULE displayLight;      ///< Einstellungen für Displaybeleuchtung
    POWERMODULE displayText;       ///< Einstellungen für Display Ein/Aus
    POWERMODULE fingerprint;       ///< Einstellungen für Fingerprintmodul Biokey3000
    POWERMODULE transponder;       ///< Einstellungen für Transponderleser
    POWERMODULE gps;               ///< Einstellungen für GPS Modul Lea 5H von ublox
    POWERMODULE usbHost;           ///< Einstellungen für USB-Host VDrive2
    POWERMODULE mmc;               ///< Einstellungen für interne MMC/SD-Karte

}POWERSETUP;


/**
@struct POWEREVENT enthält die Definition und Einstellungen eines Events
*/

typedef struct struct_power_event {

    unsigned char type;            ///< Eventtyp
    unsigned char profile;         ///< Event gültig für Energieschema Nr.
    unsigned int time;            ///< Wert der Zeit in Sekunden, auch bei Format Uhrzeit
    unsigned char nextprofile;     ///< nächstes Energieschema nach Ablauf der Aktivzeit
    unsigned char value;           ///< Wert für Analogwertüberwachung
    unsigned char channel;         ///< Eingang für den Analogwert
    unsigned char tmp[2];          ///< Reserve ab V2 der Strukturen

} POWEREVENT;



typedef struct struct_power_flags
{

    unsigned char busy;       ///< Modul arbeitet gerade, TimeOut-Zähler = 0
    unsigned int timestamp;  ///< Zeitwert ab wann Modul nicht mehr arbeitet
    unsigned int state;      ///< Modul Ein(TRUE) oder Aus(FALSE)

}POWERFLAGS;

typedef struct struct_power_state
{
    POWERFLAGS cpu;               ///< Status für Mircrocontroller
    POWERFLAGS timer;             ///< Status für Timer der Signalverarbeitung
    POWERFLAGS inputs;            ///< Status für Eingänge der Signalverarbeitung
    POWERFLAGS deviceGlobal;      ///< Status für Globale Spannungsversorgung der Baugruppe
    POWERFLAGS U5V;               ///< Status für 5V extern
    POWERFLAGS U12V;              ///< Status für 12V extern
    POWERFLAGS communication;     ///< Status für Kommunikation
    POWERFLAGS displayLight;      ///< Status für Displaybeleuchtung
    POWERFLAGS displayText;       ///< Status für Display Ein/Aus
    POWERFLAGS fingerprint;       ///< Status für Fingerprintmodul Biokey3000
    POWERFLAGS transponder;       ///< Status für Transponderleser
    POWERFLAGS gps;               ///< Status für GPS Modul Lea 5H von ublox
    POWERFLAGS usbHost;           ///< Status für USB-Host VDrive2
    POWERFLAGS mmc;               ///< Status für interne MMC/SD-Karte

}POWERSTATE;

typedef struct struct_event_timers
{

    unsigned int timerA;        ///< Zeitwert des Systemtimers Typ A
    unsigned int timerB;        ///< Zeitwert des Systemtimers Typ B
    unsigned int timerService;  ///< Zeitwert ab wann keine Bedienung mehr erfolgte
    unsigned int timerTB;       ///< Zeitwert ab wann der Timeboy gesteckt wurde
    unsigned int timerMove;     ///< Zeitwert ab wann Gerät nicht mehr bewegt wurde
    unsigned int timerCom;      ///< Zeitwert ab wann Gerät nicht mehr kommunizierte

}POWEREVENTTIMERS;

/**
@struct POWERPROPERTIES enthält die wichtigsten Grundeinstellungen des Energiemanagements
*/

typedef struct struct_power_properties
{
    unsigned char profileMaxCount;     ///< Anzahl der benutzbaren Schemen
    unsigned char activeProfile;       ///< akuelles Energieschema
    POWERSETUP profile;                ///< Struktur der einzelnen Module mit ihren Optionen
    unsigned int moduleBusy;          ///< Modul arbeitet gerade
    unsigned int moduleIdle;          ///< Modul im Leerlauf
    POWERSTATE modules;                ///< Struktur der einzelnen Module mit aktuellen Werten
    unsigned char eventMaxCount;       ///< Anzahl der Events im Setup
    unsigned char eventCount;          ///< Anzahl der Events im aktuellen Schema
    unsigned int eventStates;         ///< Energie-Events der Module
    POWEREVENTTIMERS timeEvent;            ///< Event-Timer einzelner Module

} POWERPROPERTIES;

#pragma pack(pop)
#endif
