/**
* @file  FileHardwareInfo.h
* @brief Schnittstelle fuer die Klasse FileHardwareInfo.
*/
//////////////////////////////////////////////////////////////////////
#ifndef FILEHARDWAREINFO_H
#define FILEHARDWAREINFO_H

#ifdef _MSC_VER
#pragma warning(disable : 4996)
#endif

// Verwaltungsklasse fuer Datei
#include "fileintelhex.h"
// 16bit/32bit CRC
#include "../Common/crc.h"

// Hilfsklassen fr das Verarbeiten der Dateidaten.
#include "filehardwareinfoitems.h"

#include <memory>

class FileHardwareInfo : public FileIntelHex
{
public:
    FileHardwareInfo();
	FileHardwareInfo( const FileHardwareInfo &hwInfo );
    virtual ~FileHardwareInfo();

public:
	FileHardwareInfo &operator=( const FileHardwareInfo &hwInfo );

public:
    void reset();

public:
    bool load( const std::string &filePath );
    bool save( const std::string &filePath, bool append = false );
    bool readSerialize();
    bool writeSerialize();

    bool isModified() 
    {
        return (_crc != GetCRC32( &_buffer.front(), _buffer.size() ));
    }

public:
    const std::string &filePath()
    {
        return _filePath;
    }

private:
    unsigned long _crc;

public:
    unsigned char *data()
    {
        return &_buffer.front();
    }
    const unsigned char *dataPointer( std::vector<unsigned char>::size_type offs )
    {
        return &_buffer[offs];
    }

    void setDataSize( std::vector<unsigned char>::size_type size )
    {
        _buffer.resize( size );
    }
    std::vector<unsigned char>::size_type dataSize()
    {
        return _buffer.size();
    }

public:
    ItemDeviceHardwareInfo &rootItemDeviceHardwareInfo()
    {
        return _deviceHardwareInfo;
    }
private:
    // Verwaltungsstrukturen fuer HardwareInfo
    ItemDeviceHardwareInfo _deviceHardwareInfo;

public:
    setItemBoard collectModuleIds( const setModuleId &ids );
    // Shorties
    setItemBoard moduleRS232Communication( const setModuleRS232Communication &module = moduleRS232Communication_all );
    setItemBoard moduleRS485Communication( const setModuleRS485Communication &module = moduleRS485Communication_all );
    setItemBoard moduleUSBCommunication( const setModuleUSBCommunication &module = moduleUSBCommunication_all );
    setItemBoard moduleLANCommunication( const setModuleLANCommunication &module = moduleLANCommunication_all );
    setItemBoard moduleWLANCommunication( const setModuleWLANCommunication &module = moduleWLANCommunication_all );
    setItemBoard moduleMobileCommunication( const setModuleMobileCommunication &module = moduleMobileCommunication_all );
    setItemBoard moduleBluetoothCommunication( const setModuleBluetoothCommunication &module = moduleBluetoothCommunication_all );
    setItemBoard moduleMMCCommunication( const setModuleMMCCommunication &module = moduleMMCCommunication_all );
    setItemBoard moduleUSBHostCommunication( const setModuleUSBHostCommunication &module = moduleUSBHostCommunication_all );

    setItemBoard moduleAccessControl( const setModuleAccessControl &module = moduleAccessControl_all );
    setItemBoard moduleBiokey( const setModuleBiokey &module = moduleBiokey_all );
    setItemBoard moduleGPS( const setModuleGPS &module = moduleGPS_all );

public:
    unsigned short (*signing)( unsigned char *data, std::vector<unsigned char>::size_type size );

public:
    void setAutoCorrectModulesDisabled( bool state );
};

#endif

